@@ -9,9 +9,16 @@ Released under MIT license.
 """
 
 from sprox.formbase import FormBase, EditableForm, AddRecordForm
-from sprox.widgetselector import SAWidgetSelector
 from sprox.widgets.dojo import SproxDojoSelectShuttleField, SproxDojoSortedSelectShuttleField
 
+SAWidgetSelector = None
+SAORMProvider = None
+try:
+    from sprox.sa.widgetselector import SAWidgetSelector
+    from sprox.sa.provider import SAORMProvider
+except ImportError: # pragma: no cover
+    pass
+
 class DojoSAWidgetSelector(SAWidgetSelector):
     """Dojo-Specific Widget Selector"""
     default_multiple_select_field_widget_type = SproxDojoSelectShuttleField
@@ -20,18 +27,22 @@ class DojoFormBase(FormBase):
     """FormBase for Dojo
 
     see :class:`sprox.formbase.FormBase`
-    
+
     """
-    __widget_selector_type__ = DojoSAWidgetSelector
-    
+    @property
+    def __widget_selector_type__(self):
+        if isinstance(self.__provider__, SAORMProvider):
+            return DojoSAWidgetSelector
+        return super(DojoFormBase, self).__widget_selector_type__
+
 class DojoEditableForm(EditableForm):
     """Creates a form for editing records that has select shuttles for the multiple relations.
-    
+
     :Modifiers:
       see :class:`sprox.formbase.FormBase`
 
     :Usage:
-    
+
     >>> from sprox.dojo.formbase import DojoEditableForm
     >>> from formencode import Schema
     >>> from formencode.validators import FieldsMatch
@@ -103,17 +114,21 @@ class DojoEditableForm(EditableForm):
         </table>
     </form>
 """
-    __widget_selector_type__ = DojoSAWidgetSelector
+    @property
+    def __widget_selector_type__(self):
+        if isinstance(self.__provider__, SAORMProvider):
+            return DojoSAWidgetSelector
+        return super(EditableForm, self).__widget_selector_type__
 
 class DojoAddRecordForm(AddRecordForm):
     """
     Creates a form for adding records that has select shuttles for the multiple relations.
-    
+
     :Modifiers:
       see :class:`sprox.formbase.FormBase`
 
     :Usage:
-    
+
     >>> from sprox.dojo.formbase import DojoAddRecordForm
     >>> from formencode import Schema
     >>> from formencode.validators import FieldsMatch
@@ -175,4 +190,8 @@ class DojoAddRecordForm(AddRecordForm):
         </table>
     </form>
 """
-    __widget_selector_type__ = DojoSAWidgetSelector
+    @property
+    def __widget_selector_type__(self):
+        if isinstance(self.__provider__, SAORMProvider):
+            return DojoSAWidgetSelector
+        return super(AddRecordForm, self).__widget_selector_type__
