@@ -13,12 +13,12 @@ from tw.forms import HiddenField, TableForm
 from viewbase import ViewBase, ViewBaseError
 from formencode import Schema, All
 from formencode import Validator
-from sprox.validators import UniqueValue
 from formencode.validators import UnicodeString, String
-from widgetselector import SAWidgetSelector
+
+from sprox.validators import UniqueValue
 from sprox.metadata import FieldsMetadata
-from validatorselector import SAValidatorSelector
 from sprox.widgets.widgets import SproxMethodPutHiddenField
+from sprox.viewbase import ViewBase, ViewBaseError
 
 class FilteringSchema(Schema):
     """This makes formencode work for most forms, because some wsgi apps append extra values to the parameter list."""
@@ -157,10 +157,15 @@ class FormBase(ViewBase):
     #object overrides
     __base_widget_type__       = TableForm
 
-    __widget_selector_type__   = SAWidgetSelector
+    @property
+    def __widget_selector_type__(self):
+        return self.__provider__.default_widget_selector_type
 
     __validator_selector__      = None
-    __validator_selector_type__ = SAValidatorSelector
+
+    @property
+    def __validator_selector_type__(self):
+        return self.__provider__.default_validator_selector_type
 
     __field_validators__       = None
     __field_validator_types__  = None
@@ -183,7 +188,7 @@ class FormBase(ViewBase):
         if self.__dropdown_field_names__ is None:
             self.__dropdown_field_names__ = ['name', '_name', 'description', '_description']
 
-        #bring in custom declared validators 
+        #bring in custom declared validators
         for attr in dir(self):
             if not attr.startswith('__'):
                 value = getattr(self, attr)
@@ -214,10 +219,10 @@ class FormBase(ViewBase):
                         self.__field_validator_types__[attr] = value
                 except TypeError:
                     pass
-    
-    def validate(self, params, state=None):
+
+    def validate(self, params, state=None, use_request_local=True):
         """A pass-thru to the widget's validate function."""
-        return self.__widget__.validate(params, state)
+        return self.__widget__.validate(params, state, use_request_local=use_request_local)
 
     def _do_get_widget_args(self):
         """Override this method to define how the class get's the
@@ -265,7 +270,7 @@ class FormBase(ViewBase):
 
     def _do_get_field_widgets(self, fields):
         widgets = super(FormBase, self)._do_get_field_widgets(fields)
-        widgets['sprox_id'] = HiddenField('sprox_id')
+        widgets['sprox_id'] = HiddenField('sprox_id', validator=String(if_missing=None))
         return widgets
 
     def _do_get_field_validator(self, field_name, field):
@@ -278,7 +283,7 @@ class FormBase(ViewBase):
             return
         args = self._do_get_validator_args(field_name, field, v_type)
         v = v_type(**args)
-        if hasattr(field, 'unique') and field.unique and self.__check_if_unique__:
+        if self.__check_if_unique__ and self.__provider__.is_unique_field(self.__entity__, field_name):
             v = All(UniqueValue(self.__provider__, self.__entity__, field_name), v)
         return v
 
@@ -420,7 +425,7 @@ class AddRecordForm(FormBase):
             </tr>
         </table>
     </form>
-    
+
     What is unique about the AddRecord form, is that if the fields in the database are labeled unique, it will
     automatically vaidate against uniqueness for that field.  Here is a simple user form definition, where the
     user_name in the model is unique:
@@ -497,7 +502,7 @@ class DisabledForm(FormBase):
             </tr>
         </table>
     </form>
-    
+
     You may notice in the above example that disabled fields pass in a hidden value for each disabled field.
 
     """
