@@ -1,30 +1,41 @@
-from sprox.widgets import SproxDataGrid
-from viewbase import ViewBase
-from metadata import FieldsMetadata
-from tw.api import Widget
+"""
+fillerbase Module
+
+Classes to help fill widgets with data
+
+Copyright (c) 2008-10 Christopher Perkins
+Original Version by Christopher Perkins 2008
+Released under MIT license.
+"""
 from operator import itemgetter
 
+from tw.api import Widget
+
+from sprox.viewbase import ViewBase
+from sprox.widgets import SproxDataGrid
+from sprox.metadata import FieldsMetadata
+
 class TableBase(ViewBase):
     """This class allows you to create a table widget.
 
     :Modifiers:
-    +-----------------------------------+--------------------------------------------+------------------------------+
-    | Name                              | Description                                | Default                      |
-    +===================================+============================================+==============================+
-    | __base_widget_type__              | Base widget for fields to go into.         | SproxDataGrid                |
-    +-----------------------------------+--------------------------------------------+------------------------------+
-    | __metadata_type__                 | Type the widget is based on.               | FieldsMetadata               |
-    +-----------------------------------+--------------------------------------------+------------------------------+
-    | __headers__                       | A dictionay of field/header pairs.         | {}                           |
-    +-----------------------------------+--------------------------------------------+------------------------------+
-    | __column_widths__                 | A dictionay of field/width(string) pairs.  | {}                           |
-    +-----------------------------------+--------------------------------------------+------------------------------+
-    | __default_column_width__          | Header size to use when not specified in   | '10em'                       |
-    |                                   | __column_widths__                          |                              |
-    +-----------------------------------+--------------------------------------------+------------------------------+
-    | __xml_fields__                    | fields whos values should show as html     |                              |
-    +-----------------------------------+--------------------------------------------+------------------------------+
-
+      +-----------------------------------+--------------------------------------------+------------------------------+
+      | Name                              | Description                                | Default                      |
+      +===================================+============================================+==============================+
+      | __base_widget_type__              | Base widget for fields to go into.         | SproxDataGrid                |
+      +-----------------------------------+--------------------------------------------+------------------------------+
+      | __metadata_type__                 | Type the widget is based on.               | FieldsMetadata               |
+      +-----------------------------------+--------------------------------------------+------------------------------+
+      | __headers__                       | A dictionay of field/header pairs.         | {}                           |
+      +-----------------------------------+--------------------------------------------+------------------------------+
+      | __column_widths__                 | A dictionay of field/width(string) pairs.  | {}                           |
+      +-----------------------------------+--------------------------------------------+------------------------------+
+      | __default_column_width__          | Header size to use when not specified in   | '10em'                       |
+      |                                   | __column_widths__                          |                              |
+      +-----------------------------------+--------------------------------------------+------------------------------+
+      | __xml_fields__                    | fields whos values should show as html     |                              |
+      +-----------------------------------+--------------------------------------------+------------------------------+
+  
 
     see modifiers in :mod:`sprox.viewbase`
 
@@ -41,9 +52,9 @@ class TableBase(ViewBase):
            id="None" class="grid">
         <thead>
             <tr>
-                    <th class="col_0">actions</th>
-                    <th class="col_1">town_id</th>
-                    <th class="col_2">name</th>
+                    <th  class="col_0">actions</th>
+                    <th  class="col_1">town_id</th>
+                    <th  class="col_2">name</th>
             </tr>
         </thead>
         <tbody>
@@ -121,8 +132,8 @@ class TableBase(ViewBase):
            id="None" class="grid">
         <thead>
             <tr>
-                    <th class="col_0">town_id</th>
-                    <th class="col_1">name</th>
+                    <th  class="col_0">town_id</th>
+                    <th  class="col_1">name</th>
             </tr>
         </thead>
         <tbody>
